# Hydrosphere Serving SDK


[![License](https://img.shields.io/badge/License-Apache%202.0-green.svg)](https://opensource.org/licenses/Apache-2.0)
[![PyPI version](https://badge.fury.io/py/hydrosdk.svg)](https://badge.fury.io/py/hydrosdk)

The package contains an implementation of [Hydroserving](https://github.com/Hydrospheredata/hydro-serving) API.

This package's purpose is to provide a simple and convenient way
of integrating user's workflow scripts with Serving API.

Read the full documentation [here](https://hydrospheredata.github.io/hydro-serving-sdk/).

## Installation
```
pip install hydrosdk
```

## Testing
Tested on python 3.6, 3.7, 3.8.

1. `poetry install`
2. `poetry run tox`


